@@ -287,11 +287,11 @@ class CloudFrontToApiGatewayToLambdaProps:
         :summary: The properties for the CloudFrontToApiGatewayToLambda Construct
         '''
         if isinstance(cloud_front_logging_bucket_props, dict):
-            cloud_front_logging_bucket_props = BucketProps(**cloud_front_logging_bucket_props)
+            cloud_front_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**cloud_front_logging_bucket_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = FunctionProps(**lambda_function_props)
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(log_group_props, dict):
-            log_group_props = LogGroupProps(**log_group_props)
+            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if __debug__:
             type_hints = typing.get_type_hints(CloudFrontToApiGatewayToLambdaProps.__init__)
             check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
